@@ -12,7 +12,6 @@ no strict 'refs';
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 use Lemonldap::NG::Common::Crypto
   ;    #link protected cipher Object "cypher" in configuration hash
-use Regexp::Assemble;
 use Config::IniFiles;
 
 #inherits Lemonldap::NG::Common::Conf::File
@@ -20,7 +19,7 @@ use Config::IniFiles;
 #inherits Lemonldap::NG::Common::Conf::SOAP
 #inherits Lemonldap::NG::Common::Conf::LDAP
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.3.0';
 our $msg;
 our $iniObj;
 
@@ -55,7 +54,7 @@ sub new {
         %$self = %{ $_[0] };
     }
     else {
-        if ( defined @_ && $#_ % 2 == 1 ) {
+        if ( (@_) && $#_ % 2 == 1 ) {
             %$self = @_;
         }
     }
@@ -85,7 +84,7 @@ sub new {
         }
         return 0 unless $self->prereq;
         $self->{mdone}++;
-        $msg .= "$self->{type} loaded.\n";
+        $msg = "$self->{type} loaded.\n";
     }
     if ( $self->{localStorage} and not defined( $self->{refLocalStorage} ) ) {
         eval "use $self->{localStorage};";
@@ -115,11 +114,17 @@ sub saveConf {
         return DATABASE_LOCKED if ( $self->isLocked() or not $self->lock() );
     }
     $conf->{cfgNum} = $last + 1 unless ( $self->{cfgNumFixed} );
-    foreach my $k (qw(reVHosts cipher)) {
-        delete( $conf->{$k} );
-    }
-    $msg .= "Configuration $conf->{cfgNum} stored.\n";
+    delete $conf->{cipher};
+
+    # Try to store configuration
     my $tmp = $self->store($conf);
+
+    unless ( $tmp > 0 ) {
+        $msg .= "Configuration $conf->{cfgNum} not stored.\n";
+        return ( $tmp ? $tmp : UNKNOWN_ERROR );
+    }
+
+    $msg .= "Configuration $conf->{cfgNum} stored.\n";
     return ( $self->unlock() ? $tmp : UNKNOWN_ERROR );
 }
 
@@ -133,7 +138,7 @@ sub saveConf {
 # @return Lemonldap::NG configuration
 sub getConf {
     my ( $self, $args ) = @_;
-    if (    $args->{'local'}
+    if (    $args->{local}
         and ref( $self->{refLocalStorage} )
         and my $res = $self->{refLocalStorage}->get('conf') )
     {
@@ -162,23 +167,23 @@ sub getConf {
                 $r = $self->getDBConf($args);
             }
         }
-        if ( $args->{clean} ) {
-            delete $r->{reVHosts};
+        print STDERR "Warning: key is not defined, set it in the manager !\n"
+          unless ( $r->{key} );
+        eval {
+            $r->{cipher} =
+              Lemonldap::NG::Common::Crypto->new( $r->{key}
+                  || 'lemonldap-ng-key' );
+        };
+        if ($@) {
+            $msg .= "Bad key: $@. \n";
+            return $r;
         }
-        else {
-            print STDERR
-              "Warning: key is not defined, set it in the manager !\n"
-              unless ( $r->{key} );
-            eval {
-                $r->{cipher} = Lemonldap::NG::Common::Crypto->new(
-                    $r->{key} || 'lemonldap-ng-key',
-                    Crypt::Rijndael::MODE_CBC()
-                );
-            };
-            if ($@) {
-                $msg .= "Bad key: $@. \n";
-                return $r;
-            }
+
+        # Convert old option useXForwardedForIP into trustedProxies
+        if ( defined $r->{useXForwardedForIP}
+            and $r->{useXForwardedForIP} == 1 )
+        {
+            $r->{trustedProxies} = '*';
         }
         return $r;
     }
@@ -299,12 +304,6 @@ sub getDBConf {
     }
     my $conf = $self->load( $args->{cfgNum} );
     $msg .= "Get configuration $conf->{cfgNum}.\n";
-    my $re = Regexp::Assemble->new();
-    foreach ( keys %{ $conf->{locationRules} } ) {
-        $_ = quotemeta($_);
-        $re->add($_);
-    }
-    $conf->{reVHosts} = $re->as_string;
     $self->setLocalConf($conf)
       if ( $self->{refLocalStorage} and not( $args->{noCache} ) );
     return $conf;
@@ -403,7 +402,7 @@ Web-SSO configuration.
                   # To use local cache, set :
                   localStorage => "Cache::FileCache",
                   localStorageOptions = {
-                      'namespace' => 'MyNamespace',
+                      'namespace' => 'lemonldap-ng-config',
                       'default_expires_in' => 600,
                       'directory_umask' => '007',
                       'cache_root' => '/tmp',
@@ -499,7 +498,17 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -513,10 +522,29 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2010 by Xavier Guimard
+=over
+
+=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
