@@ -76,7 +76,7 @@ sub run ($$) {
             # Add client IP as X-Forwarded-For IP in SOAP request
             my $xheader = lmHeaderIn( $apacheRequest, 'X-Forwarded-For' );
             $xheader .= ", " if ($xheader);
-            $xheader .= $apacheRequest->connection->remote_ip;
+            $xheader .= $class->ip();
             my $soapHeaders =
               HTTP::Headers->new( "X-Forwarded-For" => $xheader );
 
@@ -121,8 +121,8 @@ sub run ($$) {
                 # The cookie isn't yet available
                 $class->lmLog( "The cookie $cv isn't yet available: $@",
                     'info' );
-                $class->updateStatus( $apacheRequest->connection->remote_ip,
-                    $apacheRequest->uri, 'EXPIRED' );
+                $class->updateStatus( $class->ip(), $apacheRequest->uri,
+                    'EXPIRED' );
                 return $class->goToPortal($uri);
             }
             $datas->{$_} = $h{$_} foreach ( keys %h );
@@ -216,7 +216,7 @@ L<http://lemonldap-ng.org/>
 
 =item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
@@ -238,7 +238,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=item Copyright (C) 2012, 2013 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item Copyright (C) 2012, 2013 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
