@@ -6,6 +6,7 @@
 var helpCh={
 	'advanced':'/pages/documentation/current/start.html#advanced_features',
 	'authApache':'/pages/documentation/current/authapache.html',
+	'authBrowserID':'/pages/documentation/current/authbrowserid.html',
 	'authDBI':'/pages/documentation/current/authdbi.html',
 	'authDBIConnection':'/pages/documentation/current/authdbi.html#connection',
 	'authDBILevel':'/pages/documentation/current/authdbi.html#authentication_level',
@@ -13,6 +14,8 @@ var helpCh={
 	'authDBISchema':'/pages/documentation/current/authdbi.html#schema',
 	'authCAS':'/pages/documentation/current/authcas.html',
 	'authChoice':'/pages/documentation/current/authchoice.html',
+	'authFacebook':'/pages/documentation/current/authfacebook.html',
+	'authGoogle':'/pages/documentation/current/authgoogle.html',
 	'authLDAP':'/pages/documentation/current/authldap.html',
 	'authLDAPConnection':'/pages/documentation/current/authldap.html#connection',
 	'authLDAPFilters':'/pages/documentation/current/authldap.html#filters',
@@ -27,6 +30,7 @@ var helpCh={
 	'authSlave':'/pages/documentation/current/authslave.html',
 	'authSSL':'/pages/documentation/current/authssl.html',
 	'authTwitter':'/pages/documentation/current/authtwitter.html',
+	'authWebID':'/pages/documentation/current/authwebid.html',
 	'authYubikey':'/pages/documentation/current/authyubikey.html',
 	'cookies':'/pages/documentation/current/ssocookie.html',
 	'customfunctions':'/pages/documentation/current/customfunctions.html',
@@ -79,7 +83,7 @@ var helpCh={
 	'userdbParams':'/pages/documentation/current/start.html#authentication_and_users_database',
 	'vhostOptions':'/pages/documentation/current/configvhost.html#options',
 	'virtualHosts':'/pages/documentation/current/configvhost.html',
-	'zimbra':'/pages/documentation/current/applications/zimbra.html',
+	'zimbra':'/pages/documentation/current/applications/zimbra.html'
 };
 
 /* Init simpleTreeCollection */
@@ -193,7 +197,7 @@ $(document).ready(function(){
 		simpleTreeSetMenuStyle($.cookie("managermenu"));
 	}
 	if($.cookie("managertheme")) {
-		$("link#csstheme").attr("href",themepath+$.cookie("managertheme")+'/jquery-ui-'+jqueryuiversion+'.custom.css');
+		$("link#csstheme").attr("href",themepath+$.cookie("managertheme")+'/jquery-ui-'+jqueryuiversion+'.custom.min.css');
 	}
 	$("#css-switch #organization button").click(function(){
 		var style=$(this).attr("alt");
@@ -205,7 +209,7 @@ $(document).ready(function(){
 	$("#css-switch #theme button").click(function(){
 		var theme=$(this).attr("alt");
 		$.cookie("managertheme",theme, {expires: 365, path: '/'});
-		$("link#csstheme").attr("href",themepath+theme+'/jquery-ui-'+jqueryuiversion+'.custom.css');
+		$("link#csstheme").attr("href",themepath+theme+'/jquery-ui-'+jqueryuiversion+'.custom.min.css');
 		$('#css-switch').dialog( "close" );
 		return false;
 	});
@@ -354,7 +358,7 @@ function setlmtext(id,v,prefixvalue){
 }
 function setlminputtext(id,input,prefixvalue){
 	var inputname=$(input).attr('id');
-	var inputvalue=$(input).attr('value');
+	var inputvalue=$(input).val();
 	if(!prefixvalue){prefixvalue="";}
 	if(inputvalue.length==0){
 		alert('No '+inputname);
@@ -366,13 +370,13 @@ function setlmdata(id,v){
 	$('#text_'+safeSelector(id)).attr('value',escape(v));
 }
 function setlminputdata(id,input){
-	var inputvalue=$(input).attr('value');
+	var inputvalue=$(input).val();
 	setlmdata(id,inputvalue);
 }
 function setlmrule(id,c,r,v){
-	c=$(c).attr('value');
-	r=$(r).attr('value');
-	v=$(v).attr('value');
+	c=$(c).val();
+	r=$(r).val();
+	v=$(v).val();
 	var re=r;
 	var text=r;
 	if(c.length>0){
@@ -385,9 +389,9 @@ function setlmrule(id,c,r,v){
 	$('#text_'+safeSelector(id)).text(text);
 }
 function setlmgrantsessionrule(id,c,r,v){
-        c=$(c).attr('value');
-        r=$(r).attr('value');
-        v=$(v).attr('value') || '#';
+        c=$(c).val();
+        r=$(r).val();
+        v=$(v).val() || '#';
         var re=r;
         var text=r;
         if(c.length>0){
@@ -400,7 +404,7 @@ function setlmgrantsessionrule(id,c,r,v){
 }
 function setlmfile(id,input){
 	var inputname=$(input).attr('id');
-	if($(input).attr('value').length==0){
+	if($(input).val().length==0){
 		alert('No '+inputname);
 		return false;
 	}
@@ -422,7 +426,7 @@ function setlmfile(id,input){
 			}else{
 				data.content = data.content.replace(/&lt;/g,'<').replace(/&gt;/g,'>');
 				setlmdata(id,data.content);
-				$('#filearea').attr('value',lmdata(id));
+				$('#filearea').val(lmdata(id));
 				display('filearea',lmtext(id));
 			}
 		},
@@ -435,13 +439,10 @@ function setlmfile(id,input){
 	return false;
 }
 function setlmsamlassertion(id){
-	var ind=$('#samlAssertionIndex').attr('value');
-	var bin=$('#samlAssertionBinding').attr('value');
-	var loc=$('#samlAssertionLocation').attr('value');
-	var def='0';
-	if($('#samlAssertionDefaultOn').attr('checked')){
-		def='1';
-	}
+	var ind=$('#samlAssertionIndex').val();
+	var bin=$('#samlAssertionBinding').val();
+	var loc=$('#samlAssertionLocation').val();
+	var def=$('input[type=radio][name=samlAssertionDefaultBoolean]:checked').attr("value");
 	// Update default value in other assertions.
 	var parentId=lmparent(id);
 	var t=$('#'+parentId).find('span').get();
@@ -472,30 +473,24 @@ function setlmsamlassertion(id){
 	setlmdata(id,v);
 }
 function setlmsamlattribute(id){
-	var name=$('#samlAttributeName').attr('value');
-	var form=$('#samlAttributeFormat').attr('value');
-	var altr=$('#samlAttributeFriendlyName').attr('value');
-	var mand='0';
-	if($('#samlAttributeMandatoryOn').attr('checked')){
-		mand='1';
-	}
+	var name=$('#samlAttributeName').val();
+	var form=$('#samlAttributeFormat').val();
+	var altr=$('#samlAttributeFriendlyName').val();
+	var mand=$('input[type=radio][name=samlAttributeMandatoryBoolean]:checked').attr("value");
 	var v=mand+';'+name+';'+form+';'+altr;
-	setlmtext(id,$('#samlAttributeKey').attr('value'));
+	setlmtext(id,$('#samlAttributeKey').val());
 	setlmdata(id,v);
 }
 function setlmsamlservice(id){
-	var bin=$('#samlServiceBinding').attr('value');
-	var loc=$('#samlServiceLocation').attr('value');
-	var rep=$('#samlServiceResponseLocation').attr('value');
+	var bin=$('#samlServiceBinding').val();
+	var loc=$('#samlServiceLocation').val();
+	var rep=$('#samlServiceResponseLocation').val();
 	var v=bin+';'+loc+';'+rep;
 	setlmdata(id,v);
 }
 function setopenididplist(id){
-	var type=0;
-	var list=$('#openid_serverlist_text').attr('value');
-	if($('#openid_serverlist_white').attr('checked')){
-		type=1;
-	}
+	var type=$('input[type=radio][name=openIdServerlistBoolean]:checked').attr("value");
+	var list=$('#openid_serverlist_text').val();
 	setlmdata(id,type+';'+list);
 }
 function display(div,title) {
@@ -571,7 +566,7 @@ function authParams(id) {
 	var t=splitModuleAndOptions(lmdata(id));
 
 	// Update options field
-		$('#authOptions').attr('value',t[1]);
+		$('#authOptions').val(t[1]);
 
 	if(t[1].length>1){
 		$('#authOptions').show();
@@ -584,7 +579,7 @@ function authParams(id) {
 	$('#authText').change(function(){
 		var isMulti=false;
 		$('#content_authParams option:selected').each(function(){
-			if($(this).attr('value')=='Multi'){isMulti=true;}
+			if($(this).val()=='Multi'){isMulti=true;}
 		});
 		if(isMulti){
 			$('#authOptions').show();
@@ -603,10 +598,14 @@ function formateSelectAuth(id,value){
 	}
 	formateSelect(id,[
 		'Apache=Apache',
+		'AD=Active Directory',
+		'BrowserID=BrowserID (Mozilla Persona)',
 		'Choice=Authentication choice',
 		'CAS=Central Authentication Service (CAS)',
 		'DBI=Database (DBI)',
 		'Demo=Demonstration',
+		'Facebook=Facebook',
+		'Google=Google',
 		'LDAP=LDAP',
 		'Multi=Multiple',
 		'Null=None',
@@ -618,6 +617,7 @@ function formateSelectAuth(id,value){
 		'Slave=Slave',
 		'SSL=SSL',
 		'Twitter=Twitter',
+		'WebID=WebID',
 		'Yubikey=Yubikey'
 		],value);
 }
@@ -627,7 +627,7 @@ function userdbParams(id) {
 	var t=splitModuleAndOptions(lmdata(id));
 
 	// Update options field
-	$('#authOptions').attr('value',t[1]);
+	$('#authOptions').val(t[1]);
 
 	if(t[1].length>1){
 		$('#authOptions').show();
@@ -640,7 +640,7 @@ function userdbParams(id) {
 	$('#authText').change(function(){
 		var isMulti=false;
 		$('#content_authParams option:selected').each(function(){
-			if($(this).attr('value')=='Multi'){isMulti=true;}
+			if($(this).val()=='Multi'){isMulti=true;}
 		});
 		if(isMulti){
 			$('#authOptions').show();
@@ -658,8 +658,11 @@ function formateSelectUser(id,value){
 		value="LDAP";
 	}
 	formateSelect(id,[
+		'AD=Active Directory',
 		'DBI=Database (DBI)',
 		'Demo=Demonstration',
+		'Facebook=Facebook',
+		'Google=Google',
 		'LDAP=LDAP',
 		'Multi=Multiple',
 		'Null=None',
@@ -667,7 +670,8 @@ function formateSelectUser(id,value){
 		'Proxy=Proxy',
 		'Remote=Remote',
 		'SAML=SAML v2',
-		'Slave=Slave'
+		'Slave=Slave',
+		'WebID=WebID'
 		],value);
 }
 function passworddbParams(id) {
@@ -682,6 +686,7 @@ function formateSelectPassword(id,value){
 		value="LDAP";
 	}
 	formateSelect(id,[
+		'AD=Active Directory',
 		'DBI=Database (DBI)',
 		'Demo=Demonstration',
 		'LDAP=LDAP',
@@ -722,7 +727,7 @@ function nameIdFormatParams(id) {
 		'entity=Entity',
 		'persistent=Persistent',
 		'transient=Transient',
-		'encrypted=Encrypted',
+		'encrypted=Encrypted'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
@@ -734,7 +739,7 @@ function bindingParams(id) {
 		'http-redirect=REDIRECT',
 		'http-soap=SOAP',
 		'artifact-get=Artifact GET',
-		'artifact-post=Artifact POST',
+		'artifact-post=Artifact POST'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
@@ -754,7 +759,7 @@ function encryptionModeParams(id) {
 	formateSelect('select',[
 		'none=None',
 		'nameid=Name ID',
-		'assertion=Assertion',
+		'assertion=Assertion'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
@@ -765,7 +770,7 @@ function timeoutActivityParams(id) {
 		'900=15 min',
 		'1800=30 min',
 		'2700=45 min',
-		'3600=60 min',
+		'3600=60 min'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
@@ -775,7 +780,7 @@ function zimbraByParams(id) {
 		'=',
 		'name=User name',
 		'id=User id',
-		'foreignPrincipal=Foreign principal',
+		'foreignPrincipal=Foreign principal'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
@@ -784,43 +789,43 @@ function casAccessControlPolicyParams(id) {
 	formateSelect('select',[
 		'none=None',
 		'error=Display error on portal',
-		'faketicket=Send a fake service ticket',
+		'faketicket=Send a fake service ticket'
 		],lmdata(id));
 	display('select',lmtext(id));
 }
 function btext(id) {
 	currentId=id;
-	$('#btextKey').attr('value',lmtext(id));
-	$('#btextValue').attr('value',lmdata(id));
+	$('#btextKey').val(lmtext(id));
+	$('#btextValue').val(lmdata(id));
 	display('btext',lmtext(id));
 	$('#btextValue,#btextKey').elastic()
 	$('#newkb,#delkb').show();
 }
 function bool(id) {
 	currentId=id;
-	if(lmdata(id)==1){$('#On').attr('checked',true)}else{$('#Off').attr('checked',true)}
+	if(lmdata(id)==1){$('#On').prop('checked',true)}else{$('#Off').prop('checked',true)}
 	display('bool',lmtext(id));
 }
 function trool(id) {
 	currentId=id;
-	if(lmdata(id)==1){$('#TrOn').attr('checked',true)}
-	else{if(lmdata(id)==0){$('#TrOff').attr('checked',true)}
-	else{$('#TrDefault').attr('checked',true)}}
+	if(lmdata(id)==1){$('#TrOn').prop('checked',true)}
+	else{if(lmdata(id)==0){$('#TrOff').prop('checked',true)}
+	else{$('#TrDefault').prop('checked',true)}}
 	display('trool',lmtext(id));
 }
 function int(id) {
 	currentId=id;
-	$('#int').attr('value',lmdata(id));
+	$('#int').val(lmdata(id));
 	display('int',lmtext(id));
 }
 function text(id) {
 	currentId=id;
-	$('#text').attr('value',lmdata(id));
+	$('#text').val(lmdata(id));
 	display('text',lmtext(id));
 }
 function textarea(id) {
 	currentId=id;
-	$('#textarea').attr('value',lmdata(id));
+	$('#textarea').val(lmdata(id));
 	display('textarea',lmtext(id));
 }
 function filearea(id) {
@@ -828,7 +833,7 @@ function filearea(id) {
 	$('#urlinput').hide();
 	$('#downloadfile').hide();
 	$('#generatefile').hide();
-	$('#filearea').attr('value',lmdata(id));
+	$('#filearea').val(lmdata(id));
 	/* Only samlIDPMetaDataXML and samlSPMetaDataXML element could be loaded from URL */
 	if(lmtext(id)=='samlIDPMetaDataXML'){$('#urlinput').show();}
 	if(lmtext(id)=='samlSPMetaDataXML') {$('#urlinput').show();}
@@ -851,18 +856,18 @@ function samlAssertion(id) {
 
 	// Fill fields
 	if(t[0]==1){
-		$('#samlAssertionDefaultOn').attr('checked',true);
+		$('#samlAssertionDefaultOn').prop('checked',true);
 	}else{
-		$('#samlAssertionDefaultOff').attr('checked',true);
+		$('#samlAssertionDefaultOff').prop('checked',true);
 	}
-	$('#samlAssertionIndex').attr('value',t[1]);
+	$('#samlAssertionIndex').val(t[1]);
 	formateSelect('samlAssertionBinding',[
 		'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact=Artifact',
 		'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST=HTTP POST',
 		'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect=HTTP Redirect',
 		'urn:oasis:names:tc:SAML:2.0:bindings:SOAP=SOAP'
 		],t[2]);
-	$('#samlAssertionLocation').attr('value',t[3]);
+	$('#samlAssertionLocation').val(t[3]);
 	display('samlAssertion',lmtext(id));
 }
 function samlAttribute(id) {
@@ -876,19 +881,19 @@ function samlAttribute(id) {
 
 	// Fill fields
 	if(t[0]==1){
-		$('#samlAttributeMandatoryOn').attr('checked',true);
+		$('#samlAttributeMandatoryOn').prop('checked',true);
 	}else{
-		$('#samlAttributeMandatoryOff').attr('checked',true);
+		$('#samlAttributeMandatoryOff').prop('checked',true);
 	}
-	$('#samlAttributeKey').attr('value',lmtext(id));
-	$('#samlAttributeName').attr('value',t[1]);
+	$('#samlAttributeKey').val(lmtext(id));
+	$('#samlAttributeName').val(t[1]);
 	formateSelect('samlAttributeFormat',[
 		'=',
 		'urn:oasis:names:tc:SAML:2.0:attrname-format:unspecified=Unspecified',
 		'urn:oasis:names:tc:SAML:2.0:attrname-format:uri=URI',
 		'urn:oasis:names:tc:SAML:2.0:attrname-format:basic=Basic'
 		],t[2]);
-	$('#samlAttributeFriendlyName').attr('value',t[3]);
+	$('#samlAttributeFriendlyName').val(t[3]);
 	display('samlAttribute',lmtext(id));
 	$('#newsamlattributeb,#delsamlattributeb').show();
 }
@@ -899,7 +904,7 @@ function samlAttributeRoot(id){
 }
 function samlIdpMetaData(id){
 	currentId=id;
-	$('#samlIdpMetaData').attr('value',lmtext(id));
+	$('#samlIdpMetaData').val(lmtext(id));
 	display('samlIdpMetaData',lmtext(id));
 	if($('#li_'+myB64('/samlIDPMetaDataNode')).find('span').size()==1){
 		$('#delidpsamlmetadatab').hide();
@@ -910,7 +915,7 @@ function samlIdpMetaData(id){
 }
 function samlSpMetaData(id){
 	currentId=id;
-	$('#samlSpMetaData').attr('value',lmtext(id));
+	$('#samlSpMetaData').val(lmtext(id));
 	display('samlSpMetaData',lmtext(id));
 	if($('#li_'+myB64('/samlSPMetaDataNode')).find('span').size()==1){
 		$('#delspsamlmetadatab').hide();
@@ -928,19 +933,19 @@ function samlService(id) {
 		'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact=HTTP Artifact',
 		'urn:oasis:names:tc:SAML:2.0:bindings:SOAP=SOAP'
 		],t[0]);
-	$('#samlServiceLocation').attr('value',t[1]);
-	$('#samlServiceResponseLocation').attr('value',t[2]);
+	$('#samlServiceLocation').val(t[1]);
+	$('#samlServiceResponseLocation').val(t[2]);
 	display('samlService',lmtext(id));
 }
 function openididplist(id) {
 	currentId=id;
 	var t=lmdata(id).split(';');
 	if(t[0]==1){
-		$('#openid_serverlist_white').attr('checked',true);
+		$('#openid_serverlist_white').prop('checked',true);
 	}else{
-		$('#openid_serverlist_black').attr('checked',true);
+		$('#openid_serverlist_black').prop('checked',true);
 	}
-	$('#openid_serverlist_text').attr('value',t[1]);
+	$('#openid_serverlist_text').val(t[1]);
 	display('openid_serverlist',lmtext(id));
 }
 function securedCookieValues(id){
@@ -955,7 +960,7 @@ function securedCookieValues(id){
 }
 function vhost(id){
 	currentId=id;
-	$('#vhost').attr('value',lmtext(id));
+	$('#vhost').val(lmtext(id));
 	display('vhost',lmtext(id));
 	$('#bdelvh,#bnewvh').show();
 }
@@ -974,9 +979,10 @@ function rules(id){
 	var t=lmtext(id);
 	var b=t.match(/^(?:\(\?#(.*?)\))?(.*)/);
 	if(typeof(b[1])=='undefined')b[1]='';
-	$('#rulComment').attr('value',b[1]);
-	$('#rulKey').attr('value',b[2]);
-	$('#rulValue').attr('value',lmdata(id));
+	//$('#rulComment').val(b[1]);
+	$('#rulComment').val(b[1]);
+	$('#rulKey').val(b[2]);
+	$('#rulValue').val(lmdata(id));
 	display('rules',lmtext(lmparent(id)));
 	$('#rulComment,#rulKey,#rulValue').elastic();
 	if(t=='default'){
@@ -1002,9 +1008,9 @@ function grantSessionRules(id){
 	if(typeof(b[2])=='undefined')b[2]='';
 	var v=lmdata(id);
 	if(v=='#')v=''
-	$('#grantSessionRulKey').attr('value',b[1]);
-	$('#grantSessionRulComment').attr('value',b[2]);
-	$('#grantSessionRulValue').attr('value',v);
+	$('#grantSessionRulKey').val(b[1]);
+	$('#grantSessionRulComment').val(b[2]);
+	$('#grantSessionRulValue').val(v);
 	display('grantSessionRules',lmtext(lmparent(id)));
 	$('#grantSessionRulKey,#grantSessionRulComment,#grantSessionRulValue').elastic();
 	$('#delkb').show();
@@ -1016,9 +1022,9 @@ function grantSessionRulesRoot(id){
 	$('#newgsrbr').show();
 }
 function reloadAuthParams() {
-	var value=$('#authText').attr('value');
+	var value=$('#authText').val();
 	if($('#authOptions').is(':visible')){
-		value+=' '+$('#authOptions').attr('value');
+		value+=' '+$('#authOptions').val();
 	}
 	setlmdata(currentId,value);
 	$.ajax({
@@ -1395,7 +1401,7 @@ function authChoiceRoot(id){
 function newChoiceR(){
 	var newIdValue=newId(currentId);
 	simpleTreeCollection[0].addNode(newIdValue,text4newKey,function(d,s){
-		$('>span',s).attr('onClick','authChoice("'+newIdValue+'")').attr('name',text4newKey).attr('value','Null|Null|Null').attr('id','text_'+newIdValue);
+		$('>span',s).attr('onClick','authChoice("'+newIdValue+'")').attr('name',text4newKey).attr('value','Null|Null|Null|').attr('id','text_'+newIdValue);
 		authChoice(newIdValue);
 	});
 	return false;
@@ -1403,7 +1409,7 @@ function newChoiceR(){
 function newChoice(){
 	var newIdValue=newId(currentId);
 	simpleTreeCollection[0].newNodeAfter(newIdValue,text4newKey,function(d,s){
-		$('>span',s).attr('onClick','authChoice("'+newIdValue+'")').attr('name',text4newKey).attr('value','Null|Null|Null').attr('id','text_'+newIdValue);
+		$('>span',s).attr('onClick','authChoice("'+newIdValue+'")').attr('name',text4newKey).attr('value','Null|Null|Null|').attr('id','text_'+newIdValue);
 		authChoice(newIdValue);
 	});
 	return false;
@@ -1414,20 +1420,22 @@ function delChoice(){
 function authChoice(id){
 	currentId=id;
 	var t=lmdata(id).split('|');
-	$('#authChoiceKey').attr('value',lmtext(id));
+	$('#authChoiceKey').val(lmtext(id));
 	formateSelectAuth('authChoiceAuth',t[0]);
 	formateSelectUser('authChoiceUser',t[1]);
 	formateSelectPassword('authChoicePassword',t[2]);
+	$('#authChoiceURL').val(t[3]);
 	display('authChoice',lmtext(id));
 	$('#newchoice,#delchoice').show();
 }
 function setlmauthchoice(id){
-	var key=$('#authChoiceKey').attr('value');
-	var auth=$('#authChoiceAuth').attr('value');
-	var user=$('#authChoiceUser').attr('value');
-	var password=$('#authChoicePassword').attr('value');
+	var key=$('#authChoiceKey').val();
+	var auth=$('#authChoiceAuth').val();
+	var user=$('#authChoiceUser').val();
+	var password=$('#authChoicePassword').val();
+	var url=$('#authChoiceURL').val();
 	setlmtext(id,key);
-	setlmdata(id,auth+'|'+user+'|'+password);
+	setlmdata(id,auth+'|'+user+'|'+password+'|'+url);
 }
 
 /* Application list */
@@ -1454,8 +1462,8 @@ function delCategory(){
 
 function applicationListCategory(id){
 	currentId=id;
-	$('#applicationListCategoryKey').attr('value',lmtext(id));
-	$('#applicationListCategoryName').attr('value',lmdata(id));
+	$('#applicationListCategoryKey').val(lmtext(id));
+	$('#applicationListCategoryName').val(lmdata(id));
 	display('applicationListCategory',lmtext(id));
 	$('#delcategory,#newapplicationr').show();
 }
@@ -1476,28 +1484,28 @@ function delApplication(){
 }
 
 function setlmapplication(id){
-	var key=$('#applicationListApplicationKey').attr('value');
-	var name=$('#applicationListApplicationName').attr('value');
-	var url=$('#applicationListApplicationURL').attr('value');
-	var desc=$('#applicationListApplicationDescription').attr('value');
-	var logo=$('#applicationListApplicationLogo').attr('value');
-	var display=$('#applicationListApplicationDisplay').attr('value');
+	var key=$('#applicationListApplicationKey').val();
+	var name=$('#applicationListApplicationName').val();
+	var url=$('#applicationListApplicationURL').val();
+	var desc=$('#applicationListApplicationDescription').val();
+	var logo=$('#applicationListApplicationLogo').val();
+	var display=$('#applicationListApplicationDisplay').val();
 	setlmtext(id,key);
 	setlmdata(id,name+'|'+url+'|'+desc+'|'+logo+'|'+display);
 }
 
 function applicationListApplication(id){
 	currentId=id;
-	$('#applicationListApplicationKey').attr('value',lmtext(id));
+	$('#applicationListApplicationKey').val(lmtext(id));
 	var t=lmdata(id).split('|');
-	$('#applicationListApplicationName').attr('value',t[0]);
-	$('#applicationListApplicationURL').attr('value',t[1]);
-	$('#applicationListApplicationDescription').attr('value',t[2]);
+	$('#applicationListApplicationName').val(t[0]);
+	$('#applicationListApplicationURL').val(t[1]);
+	$('#applicationListApplicationDescription').val(t[2]);
 	changeAppsLogo(t[3]);
 	formateSelect('applicationListApplicationDisplay',[
 		'auto=Automatic',
 		'on=On',
-		'off=Off',
+		'off=Off'
 		],t[4]);
 	display('applicationListApplication',lmtext(id));
 	$('#delapplication').show();
@@ -1550,8 +1558,8 @@ function newPostDataR(){
 
 function post(id){
 	currentId=id;
-	$('#postKey').attr('value',lmtext(id));
-	$('#postUrl').attr('value',lmdata(id));
+	$('#postKey').val(lmtext(id));
+	$('#postUrl').val(lmdata(id));
 	display('post',lmtext(lmparent(id)));
 	$('#delpost,#newpostdatar').show();
 }
@@ -1559,8 +1567,8 @@ function post(id){
 function postData(id){
 	currentId=id;
 	var cleankey = lmtext(id).replace('postdata:','');
-	$('#postDataKey').attr('value',cleankey);
-	$('#postDataValue').attr('value',lmdata(id));
+	$('#postDataKey').val(cleankey);
+	$('#postDataValue').val(lmdata(id));
 	display('postdata',cleankey);
 	$('#delpostdata').show();
 }
@@ -1582,8 +1590,8 @@ function popup(html){
 		buttons: {
 			Ok: function() {
 			$( this ).dialog( "close" );
-			},
-		},
+			}
+		}
 	});
 }
 
@@ -1625,12 +1633,12 @@ function boolOrPerlExpr(id){
 	$('#bopeValue').val('');
 	$('#bopeValue').hide();
 	if(lmdata(id)==1){
-		$('#bopeOn').attr('checked',true);
+		$('#bopeOn').prop('checked',true);
 	}else{
 		if(lmdata(id)==0){
-			$('#bopeOff').attr('checked',true);
+			$('#bopeOff').prop('checked',true);
 		}else{
-			$('#bopeExpr').attr('checked',true);
+			$('#bopeExpr').prop('checked',true);
 			$('#bopeValue').val(lmdata(id));
 			$('#bopeValue').show();
 		}
@@ -1639,7 +1647,7 @@ function boolOrPerlExpr(id){
 }
 
 function setlmbope(id){
-	if($('#bopeExpr:checked').val()=='-1'){
+	if($('input[type=radio][name=bope]:checked').attr("value")=='-1'){
 		setlmdata(id,$('#bopeValue').val());
 	}
 }
