@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.2.3';
+our $VERSION = '1.3.0';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -48,74 +48,86 @@ __END__
 
 sub en {
     return {
-        _auth                  => 'Authentication',
-        _authChoice            => 'Authentication choice',
-        _userDB                => 'User',
-        _passwordDB            => 'Password',
-        _issuerDB              => 'Issuer',
-        _timezone              => 'Time zone',
-        _session_id            => 'Session identifier',
-        _url                   => 'Origin URL',
-        _user                  => 'Login',
-        _password              => 'Password',
-        _utime                 => 'Session timestamp',
-        _lastAuthnUTime        => 'Authentication timestamp',
-        _idp                   => 'IDP EntityID',
-        _idpConfKey            => 'IDP configuration key',
-        _samlToken             => 'SAML token',
-        _lassoSessionDump      => 'Lasso session dump',
-        _lassoIdentityDump     => 'Lasso identity dump',
-        advancedParams         => 'Advanced parameters',
-        apacheParams           => 'Apache parameters',
-        apacheAuthnLevel       => 'Authentication level',
-        applicationList        => 'Categories and applications',
-        attributesAndMacros    => 'Attributes and macros',
-        authChoiceModules      => 'Allowed modules',
-        authChoiceParam        => 'URL parameter',
-        authentication         => 'Authentication module',
-        authenticationLevel    => 'Authentication level',
-        authenticationTitle    => 'Authentication',
-        AuthLDAPFilter         => 'Authentication filter',
-        authParams             => 'Authentication modules',
-        dbiAuthChain           => 'Chain',
-        dbiAuthLoginCol        => 'Login field name',
-        dbiAuthnLevel          => 'Authentication level',
-        dbiAuthPassword        => 'Password',
-        dbiAuthPasswordCol     => 'Password field name',
-        dbiAuthPasswordHash    => 'Hash scheme',
-        dbiAuthTable           => 'Authentication table',
-        dbiAuthUser            => 'User',
-        dbiConnection          => 'Connection',
-        dbiConnectionAuth      => 'Authentication process',
-        dbiConnectionUser      => 'User process',
-        dbiParams              => 'DBI parameters',
-        dbiPassword            => 'Password',
-        dbiPasswordMailCol     => 'Mail field name',
-        dbiSchema              => 'Schema',
-        dbiUserChain           => 'Chain',
-        dbiUserPassword        => 'Password',
-        dbiUserTable           => 'User table',
-        dbiUserUser            => 'User',
-        deleteNotification     => 'Mark notification as done',
-        deleteSession          => 'Delete session',
-        done                   => 'done',
-        CAS_authnLevel         => 'Authentication level',
-        CAS_CAFile             => 'CA file',
-        CAS_gateway            => 'Gateway authentication',
-        CAS_pgtFile            => 'PGT file',
-        CAS_proxiedServices    => 'Proxied services',
-        CAS_renew              => 'Renew authentication',
-        CAS_url                => 'Server URL',
-        casAccessControlPolicy => 'Access control policy',
-        casAttr                => 'CAS login',
-        casParams              => 'CAS parameters',
-        casStorage             => 'CAS sessions module name',
-        casStorageOptions      => 'CAS sessions module options',
-        cda                    => 'Multiple domains',
-        checkXSS               => 'Check XSS attacks',
-        clickHereToForce       => 'Click here to force',
-        choiceParams           => 'Choice parameters',
-        Configuration          => 'Configuration',
+        _auth                    => 'Authentication',
+        _authChoice              => 'Authentication choice',
+        _userDB                  => 'User',
+        _passwordDB              => 'Password',
+        _issuerDB                => 'Issuer',
+        _timezone                => 'Time zone',
+        _session_id              => 'Session identifier',
+        _url                     => 'Origin URL',
+        _user                    => 'Login',
+        _password                => 'Password',
+        _utime                   => 'Session timestamp',
+        _lastAuthnUTime          => 'Authentication timestamp',
+        _idp                     => 'IDP EntityID',
+        _idpConfKey              => 'IDP configuration key',
+        _samlToken               => 'SAML token',
+        _lassoSessionDump        => 'Lasso session dump',
+        _lassoIdentityDump       => 'Lasso identity dump',
+        advancedParams           => 'Advanced parameters',
+        apacheParams             => 'Apache parameters',
+        apacheAuthnLevel         => 'Authentication level',
+        applicationList          => 'Categories and applications',
+        attributesAndMacros      => 'Attributes and macros',
+        authChoiceModules        => 'Allowed modules',
+        authChoiceParam          => 'URL parameter',
+        authentication           => 'Authentication module',
+        authenticationLevel      => 'Authentication level',
+        authenticationTitle      => 'Authentication',
+        AuthLDAPFilter           => 'Authentication filter',
+        authParams               => 'Authentication modules',
+        browserIdAuthnLevel      => 'Authentication level',
+        browserIdAutoLogin       => 'Automatic login',
+        browserIdBackgroundColor => 'Background color',
+        browserIdParams          => 'BrowserIDParams',
+        browserIdSiteLogo        => 'Site Logo',
+        browserIdSiteName        => 'Site name',
+        browserIdVerificationURL => 'Verification URL',
+        dbiAuthChain             => 'Chain',
+        dbiAuthLoginCol          => 'Login field name',
+        dbiAuthnLevel            => 'Authentication level',
+        dbiAuthPassword          => 'Password',
+        dbiAuthPasswordCol       => 'Password field name',
+        dbiAuthPasswordHash      => 'Hash scheme',
+        dbiAuthTable             => 'Authentication table',
+        dbiAuthUser              => 'User',
+        dbiConnection            => 'Connection',
+        dbiConnectionAuth        => 'Authentication process',
+        dbiConnectionUser        => 'User process',
+        dbiParams                => 'DBI parameters',
+        dbiPassword              => 'Password',
+        dbiPasswordMailCol       => 'Mail field name',
+        dbiSchema                => 'Schema',
+        dbiUserChain             => 'Chain',
+        dbiUserPassword          => 'Password',
+        dbiUserTable             => 'User table',
+        dbiUserUser              => 'User',
+        deleteNotification       => 'Mark notification as done',
+        deleteSession            => 'Delete session',
+        done                     => 'done',
+        captcha_data             => 'Directory for data',
+        captcha_login_enabled    => 'Activation in login form',
+        captcha_mail_enabled     => 'Activation in password reset by mail form',
+        captcha_output           => 'Directory for images',
+        captcha_size             => 'Size',
+        CAS_authnLevel           => 'Authentication level',
+        CAS_CAFile               => 'CA file',
+        CAS_gateway              => 'Gateway authentication',
+        CAS_pgtFile              => 'PGT file',
+        CAS_proxiedServices      => 'Proxied services',
+        CAS_renew                => 'Renew authentication',
+        CAS_url                  => 'Server URL',
+        casAccessControlPolicy   => 'Access control policy',
+        casAttr                  => 'CAS login',
+        casParams                => 'CAS parameters',
+        casStorage               => 'CAS sessions module name',
+        casStorageOptions        => 'CAS sessions module options',
+        cda                      => 'Multiple domains',
+        checkXSS                 => 'Check XSS attacks',
+        clickHereToForce         => 'Click here to force',
+        choiceParams             => 'Choice parameters',
+        Configuration            => 'Configuration',
         confModuledeprecated =>
 'This module has been deprecated, set "forceUpload=1" in lemonldap-ng.ini to use it',
         confSaved                       => 'Configuration saved',
@@ -132,10 +144,16 @@ sub en {
         error                           => 'Error',
         exportedAttr                    => 'SOAP exported attributes',
         exportedVars                    => 'Exported Variables',
+        facebookAppId                   => 'Facebook application ID',
+        facebookAppSecret               => 'Facebook application secret',
+        facebookAuthnLevel              => 'Authentication level',
+        facebookParams                  => 'Facebook parameters',
         failedLoginNumber               => 'Number of registered failed logins',
         generalParameters               => 'General Parameters',
         globalStorage                   => 'Apache::Session module',
         globalStorageOptions            => 'Apache::Session module parameters',
+        googleAuthnLevel                => 'Authentication level',
+        googleParams                    => 'Google parameters',
         grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
@@ -260,6 +278,7 @@ sub en {
         portal                      => 'URL',
         portalAntiFrame             => 'Anti frame protection',
         portalAutocomplete          => 'Auto complete',
+        portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Check last logins',
         portalCustomization         => 'Customization',
         portalDisplayAppslist       => 'Applications list',
@@ -357,12 +376,16 @@ sub en {
         useRedirectOnForbidden      => 'Redirect on forbidden',
         useSafeJail                 => 'Use Safe jail',
         variables                   => "Variables",
+        vhostAliases                => 'Aliases',
         vhostHttps                  => 'HTTPS',
         vhostMaintenance            => 'Maintenance mode',
         vhostOptions                => 'Options',
         vhostPort                   => 'Port',
         virtualHosts                => 'Virtual Hosts',
         warning                     => 'Warning',
+        webIDAuthnLevel             => 'Authentication level',
+        webIDParams                 => 'WebID parameters',
+        webIDWhitelist              => 'WebID whitelist',
         whatToTrace                 => "REMOTE_USER",
         yubikeyAuthnLevel           => 'Authentication level',
         yubikeyClientID             => 'API client ID',
@@ -492,63 +515,78 @@ sub en {
         samlCommonDomainCookieDomain     => 'Common domain',
         samlCommonDomainCookieReader     => 'Reader URL',
         samlCommonDomainCookieWriter     => 'Writer URL',
+        samlRelayStateTimeout            => 'RelayState session timeout',
     };
 }
 
 sub fr {
     use utf8;
     return {
-        _auth                  => 'Authentification',
-        _authChoice            => 'Choix d\'authentification',
-        _userDB                => 'Utilisateur',
-        _passwordDB            => 'Mot de passe',
-        _issuerDB              => 'Fournisseur',
-        _timezone              => 'Zone horaire',
-        _session_id            => 'Identifiant de session',
-        _url                   => "URL d'origine",
-        _user                  => 'Identifiant',
-        _password              => 'Mot de passe',
-        _utime                 => 'Tampon de la session',
-        _lastAuthnUTime        => 'Tampon d\'authentification ',
-        _idp                   => 'Identifiant d\'entité de l\'IDP',
-        _idpConfKey            => 'Clé de configuration de l\'IDP',
-        _samlToken             => ' Jeton SAML ',
-        _lassoSessionDump      => ' Dump session Lasso ',
-        _lassoIdentityDump     => 'Dump identité Lasso',
-        advancedParams         => 'Paramètres avancés',
-        apacheParams           => 'Paramètres Apache',
-        apacheAuthnLevel       => 'Niveau d\'authentification',
-        applicationList        => 'Catégories et applications',
-        attributesAndMacros    => 'Attributs et macros',
-        authChoiceModules      => 'Modules autorisés',
-        authChoiceParam        => 'Parmètre de l\'URL',
-        authentication         => "Module d'authentification",
-        authenticationLevel    => 'Niveau d\'authentification',
-        authenticationTitle    => 'Authentification',
-        AuthLDAPFilter         => 'Filtre d\'authentification',
-        authParams             => "Modules d'authentification",
-        dbiAuthChain           => 'Chaîne',
-        dbiAuthLoginCol        => 'Champ identifiant',
-        dbiAuthnLevel          => 'Niveau d\'authentification',
-        dbiAuthPassword        => 'Mot de passe',
-        dbiAuthPasswordCol     => 'Champ mot de passe',
-        dbiAuthPasswordHash    => 'Schéma de hachage',
-        dbiAuthTable           => 'Table authentification',
-        dbiAuthUser            => 'Utilisateur',
-        dbiConnection          => 'Connexion',
-        dbiConnectionAuth      => 'Authentification',
-        dbiConnectionUser      => 'Utilisateurs',
-        dbiParams              => 'Paramètres DBI',
-        dbiPassword            => 'Mot de passe',
-        dbiPasswordMailCol     => 'Champ mail',
-        dbiSchema              => 'Schéma',
-        dbiUserChain           => 'Chaîne',
-        dbiUserPassword        => 'Mot de passe',
-        dbiUserTable           => 'Table des utilisateurs',
-        dbiUserUser            => 'Utilisateur',
-        deleteNotification     => 'Marquer la notification comme validée',
-        deleteSession          => 'Effacer la session',
-        done                   => 'validée',
+        _auth                    => 'Authentification',
+        _authChoice              => 'Choix d\'authentification',
+        _userDB                  => 'Utilisateur',
+        _passwordDB              => 'Mot de passe',
+        _issuerDB                => 'Fournisseur',
+        _timezone                => 'Zone horaire',
+        _session_id              => 'Identifiant de session',
+        _url                     => "URL d'origine",
+        _user                    => 'Identifiant',
+        _password                => 'Mot de passe',
+        _utime                   => 'Tampon de la session',
+        _lastAuthnUTime          => 'Tampon d\'authentification ',
+        _idp                     => 'Identifiant d\'entité de l\'IDP',
+        _idpConfKey              => 'Clé de configuration de l\'IDP',
+        _samlToken               => ' Jeton SAML ',
+        _lassoSessionDump        => ' Dump session Lasso ',
+        _lassoIdentityDump       => 'Dump identité Lasso',
+        advancedParams           => 'Paramètres avancés',
+        apacheParams             => 'Paramètres Apache',
+        apacheAuthnLevel         => 'Niveau d\'authentification',
+        applicationList          => 'Catégories et applications',
+        attributesAndMacros      => 'Attributs et macros',
+        authChoiceModules        => 'Modules autorisés',
+        authChoiceParam          => 'Parmètre de l\'URL',
+        authentication           => "Module d'authentification",
+        authenticationLevel      => 'Niveau d\'authentification',
+        authenticationTitle      => 'Authentification',
+        AuthLDAPFilter           => 'Filtre d\'authentification',
+        authParams               => "Modules d'authentification",
+        browserIdAuthnLevel      => "Niveau d'authentification",
+        browserIdAutoLogin       => "Authentification automatique",
+        browserIdBackgroundColor => "Couleur d'arrière plan",
+        browserIdParams          => "Paramètres BrowserID",
+        browserIdSiteLogo        => "Logo du site",
+        browserIdSiteName        => "Nom du site",
+        browserIdVerificationURL => "Adresse de vérification",
+        dbiAuthChain             => 'Chaîne',
+        dbiAuthLoginCol          => 'Champ identifiant',
+        dbiAuthnLevel            => 'Niveau d\'authentification',
+        dbiAuthPassword          => 'Mot de passe',
+        dbiAuthPasswordCol       => 'Champ mot de passe',
+        dbiAuthPasswordHash      => 'Schéma de hachage',
+        dbiAuthTable             => 'Table authentification',
+        dbiAuthUser              => 'Utilisateur',
+        dbiConnection            => 'Connexion',
+        dbiConnectionAuth        => 'Authentification',
+        dbiConnectionUser        => 'Utilisateurs',
+        dbiParams                => 'Paramètres DBI',
+        dbiPassword              => 'Mot de passe',
+        dbiPasswordMailCol       => 'Champ mail',
+        dbiSchema                => 'Schéma',
+        dbiUserChain             => 'Chaîne',
+        dbiUserPassword          => 'Mot de passe',
+        dbiUserTable             => 'Table des utilisateurs',
+        dbiUserUser              => 'Utilisateur',
+        deleteNotification       => 'Marquer la notification comme validée',
+        deleteSession            => 'Effacer la session',
+        done                     => 'validée',
+        captcha_data             => 'Répertoire des données',
+        captcha_login_enabled =>
+          "Activation dans le formulaire d'authentification",
+        captcha_mail_enabled =>
+          'Activation dans le formulaire de réinitialisation par mail',
+        captcha_output         => 'Répertoire des images',
+        captcha_size           => 'Taille',
         CAS_authnLevel         => 'Niveau d\'authentification',
         CAS_CAFile             => 'Fichier d\'AC',
         CAS_gateway            => 'Authentification transparente',
@@ -582,10 +620,16 @@ sub fr {
         error          => 'Erreur',
         exportedAttr   => 'Attributs exportés par le portail (SOAP)',
         exportedVars   => 'Attributs à exporter',
+        facebookAppId  => 'ID de l\'application Facebook',
+        facebookAppSecret      => 'Secret de l\'application Facebook',
+        facebookAuthnLevel     => 'Niveau d\'authentification',
+        facebookParams         => 'Paramètres Facebook',
         failedLoginNumber      => 'Nombre d\'échecs de connexion mémorisés',
         generalParameters      => 'Paramètres généraux',
         globalStorage          => 'Module Apache::Session',
         globalStorageOptions   => 'Paramètres du module Apache::Session',
+        googleAuthnLevel       => 'Niveau d\'authentification',
+        googleParams           => 'Paramètres Google',
         grantSessionRules      => "Conditions d'ouverture",
         groups                 => 'Groupes',
         headers                => 'En-têtes HTTP',
@@ -715,6 +759,7 @@ sub fr {
         portal                      => 'URL',
         portalAntiFrame             => 'Protection anti frame',
         portalAutocomplete          => 'Auto complétion',
+        portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Vérifier l\'historique',
         portalCustomization         => 'Personnalisation',
         portalDisplayAppslist       => 'Liste des applications',
@@ -813,12 +858,16 @@ sub fr {
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
         useSafeJail            => 'Utiliser la cage Safe',
         variables              => "Variables",
+        vhostAliases           => 'Alias',
         vhostHttps             => 'HTTPS',
         vhostMaintenance       => 'Mode maintenance',
         vhostOptions           => 'Options',
         vhostPort              => 'Port',
         virtualHosts           => 'Hôtes virtuels',
         warning                => 'Attention',
+        webIDAuthnLevel        => 'Niveau d\'authentification',
+        webIDParams            => 'Paramètres WebID',
+        webIDWhitelist         => 'Liste blanche WebID',
         whatToTrace            => "REMOTE_USER",
         yubikeyAuthnLevel      => "Niveau d'authentification",
         yubikeyClientID        => "Identifiant client de l'API",
@@ -957,6 +1006,7 @@ sub fr {
         samlCommonDomainCookieDomain     => 'Domaine commun',
         samlCommonDomainCookieReader     => 'URL de lecture',
         samlCommonDomainCookieWriter     => 'URL d\'écriture',
+        samlRelayStateTimeout => 'Durée de vie d\'une session RelayState',
     };
 }
 
