@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.3.1';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -1148,20 +1148,36 @@ sub authenticate {
 sub getIDP {
     my $self = shift;
     my $idp;
+    my $idpName;
 
     my %cookies    = fetch CGI::Cookie;
     my $idp_cookie = $cookies{ $self->{samlIdPResolveCookie} };
     $idp_cookie &&= $idp_cookie->value;
 
-    # Case 1: Recover IDP from args
+    # Case 1: Recover IDP from idp URL Parameter
     unless ( $idp = $self->param("idp") ) {
 
-        # Case 2: Recover IDP from cookie
-        if ( $idp = $idp_cookie ) {
+        # Case 2: Recover IDP from idpName URL Parameter
+        if ( $idpName = $self->param("idpName") ) {
+            foreach ( keys %{ $self->{_idpList} } ) {
+                my $idpConfKey = $self->{_idpList}->{$_}->{confKey};
+                if ( $idpName eq $idpConfKey ) {
+                    $idp = $_;
+                    $self->lmLog(
+                        "IDP $idp found from idpName URL Parameter ($idpName)",
+                        'debug'
+                    );
+                    last;
+                }
+            }
+        }
+
+        # Case 3: Recover IDP from cookie
+        if ( !$idp and $idp = $idp_cookie ) {
             $self->lmLog( "IDP $idp found in IDP resolution cookie", 'debug' );
         }
 
-        # Case 3: check all IDP resolution rules
+        # Case 4: check all IDP resolution rules
         # The first match win
         else {
             foreach ( keys %{ $self->{_idpList} } ) {
@@ -1179,7 +1195,7 @@ sub getIDP {
             }
         }
 
-        # Case 4: use Common Domain Cookie
+        # Case 5: use Common Domain Cookie
         if (   !$idp
             and $self->{samlCommonDomainCookieActivation}
             and $self->{samlCommonDomainCookieReader} )
@@ -1484,7 +1500,7 @@ L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::UserDBSAML>, L<Lemonldap::NG:
 
 =item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
@@ -1512,7 +1528,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
 
-=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
