@@ -12,7 +12,7 @@ use Lemonldap::NG::Portal::_LibAccess;
 use base qw(Lemonldap::NG::Portal::_LibAccess);
 use Clone qw(clone);
 
-our $VERSION  = '1.1.0';
+our $VERSION  = '1.3.0';
 our $catlevel = 0;
 
 ## @method void menuInit()
@@ -48,7 +48,7 @@ sub menuInit {
 
     # Default to appslist if invalid tab URL parameter
     $self->{menuDisplayTab} = "appslist"
-      unless ( $self->{menuDisplayTab} =~ /^(password|logout)$/ );
+      unless ( $self->{menuDisplayTab} =~ /^(password|logout|loginHistory)$/ );
 
     # Force password tab in case of password error
     $self->{menuDisplayTab} = "password"
@@ -580,7 +580,7 @@ L<Lemonldap::NG::Portal>, L<http://lemonldap-ng.org/>
 
 =item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
@@ -602,7 +602,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
