@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::_Choice;
 
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.3.1';
 
 ## @cmethod Lemonldap::NG::Portal::_Choice new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
@@ -32,6 +32,13 @@ sub new {
         $portal->{_authChoice} = "";
     }
 
+    # Special workaround for Captcha
+    # Init Captcha to have it displayed even if no choice already done
+    if ( $portal->{captcha_login_enabled} ) {
+        eval { $portal->initCaptcha(); };
+        $portal->lmLog( "Can't init captcha: $@", "error" ) if $@;
+    }
+
     # Special workaround for SAML
     # because we cannot easily set SSO return URL
     # and SLO URL with authChoice parameter
@@ -41,7 +48,7 @@ sub new {
         my $samlModule = 'Lemonldap::NG::Portal::AuthSAML';
         my $samlForce  = 0;
         eval {
-            $portal->loadModule($samlModule);
+            $portal->loadModule( $samlModule, 1 );
             $authForce = $samlModule . '::authForce';
             $samlForce = $portal->$authForce;
         };
@@ -181,13 +188,17 @@ sub _buildAuthLoop {
         $name =~ s/\_/ /g;
 
         # Find modules associated to authChoice
-        my ( $auth, $userDB, $passwordDB ) =
+        my ( $auth, $userDB, $passwordDB, $url ) =
           split( /\|/, $self->{authChoiceModules}->{$_} );
 
         if ( $auth and $userDB and $passwordDB ) {
 
+            # Default URL
+            $url ||= "#";
+
             # Options to store in the loop
-            my $optionsLoop = { name => $name, key => $_, module => $auth };
+            my $optionsLoop =
+              { name => $name, key => $_, module => $auth, url => $url };
 
             # Get displayType for this module
             my $modulePrefix = 'Lemonldap::NG::Portal::';
